==> version4_v4.0.4_lgpl.tgz: Version4_lgpl/Dragon/src/LIBDEP.f <==
*DECK LIBDEP
      SUBROUTINE LIBDEP(IPLIB,IMPX,NDEPL)
*
*-----------------------------------------------------------------------
*
*Purpose:
* read the information related to the depletion calculation.
*
*Copyright:
* Copyright (C) 2002 Ecole Polytechnique de Montreal
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
*
*Author(s): A. Hebert and G. Marleau
*
*Parameters: input
* IPLIB   pointer to the internal microscopic cross section library
*         (L_LIBRARY signature).
* IMPX    print flag.
*
*Parameters: output
* NDEPL   number of depleting isotopes.
*
*-----------------------------------------------------------------------
*
      IMPLICIT NONE
*----
*  SUBROUTINE ARGUMENTS
*----
      INTEGER IPLIB,IMPX,NDEPL
*----
*  LOCAL PARAMETERS
*----
      INTEGER          IOUT,NSTATE,MAXR,INDIC,NEL,IEVOT,NITMA,IPDRL,
     >                 NDFI,NDFP,NHEAVY,NLIGHT,NOTHER,NSTABL,NREAC,
     >                 NPAR,INAM,IIZAE,IHREAC,IDR,IRER,IRRD,IKPAR,
     >                 IBPAR,IYIELD,ITNAM,ITZEA,MATNO,JKPAX,JBPAX,
     >                 ITEXT4,I,J,ISTA,ILONG,ITYLCM,ICHILD,IBURND,
     >                 IIWISO
      REAL             FLOTT,RBASE
      PARAMETER       (IOUT=6,NSTATE=40,MAXR=12)
      DOUBLE PRECISION DBLINP
      CHARACTER        NMDEPL(MAXR)*8,TEXT4*4,HSMG*131,CFILNA*64,
     >                 HHLIB*6,TEXT12*12,NAMLCM*12,NAMMY*12
      LOGICAL          EMPTY,LCM
      INTEGER          ISTATE(NSTATE)
*----
*  MEMORY ALLOCATION
*----
      INTEGER          IBASE(1)
      COMMON           RBASE(1)
      EQUIVALENCE     (RBASE(1),IBASE(1))
*
      SAVE      NMDEPL
      DATA      NMDEPL/'DECAY   ','NFTOT   ','NG      ','N2N     ',
     >                 'N3N     ','N4N     ','NA      ','NP      ',
     >                 'N2A     ','NNP     ','ND      ','NT      '/
*----
*  READ INFORMATION AVAILABLE ON INPUT
*----
      CALL REDGET(INDIC,NEL,FLOTT,TEXT4,DBLINP)
      IF(INDIC.EQ.1) THEN
         IEVOT=0
      ELSE IF((INDIC.EQ.3).AND.(TEXT4.EQ.'LIB:')) THEN
        CALL REDGET(INDIC,NITMA,FLOTT,HHLIB,DBLINP)
        IF(INDIC.NE.3) THEN
          CALL XABORT('LIBDEP: CHARACTER LIBRARY NAME REQUIRED.')
        ELSE IF((HHLIB.NE.'DRAGON  ') .AND. (HHLIB.NE.'WIMS    ') .AND.
     >          (HHLIB.NE.'WIMSD4  ') .AND. (HHLIB.NE.'APLIB2  ') .AND.
     >          (HHLIB.NE.'NDAS    ')       ) THEN
          WRITE(HSMG,'(30HLIBDEP: INVALID EVOL LIB TYPE ,A6)') HHLIB
          CALL XABORT(HSMG)
        ENDIF
        CALL REDGET(INDIC,NITMA,FLOTT,TEXT4,DBLINP)
        IF((INDIC.NE.3).OR.(TEXT4.NE.'FIL:'))
     >    CALL XABORT('LIBDEP: FIL: EXPECTED.')
        CFILNA=' '
        CALL REDGET(INDIC,NITMA,FLOTT,CFILNA,DBLINP)
        IF(INDIC.NE.3) CALL XABORT('LIBDEP: CHARACTER DATA EXPECTED.')
        IF(HHLIB.EQ.'DRAGON') THEN
          TEXT12=CFILNA
          CALL LCMINF(IPLIB,NAMLCM,NAMMY,EMPTY,ILONG,LCM)
          IF(TEXT12.EQ.NAMLCM) THEN
            IPDRL=IPLIB
          ELSE
            CALL LCMOP(IPDRL,TEXT12,2,2,0)
          ENDIF
          CALL LCMLEN(IPDRL,'DEPL-CHAIN',ILONG,ITYLCM)
          IF(ILONG.EQ.0) THEN
             CALL XABORT('LIBDEP: NO BURNUP DATA ON DRAGLIB NAMED '//
     >       TEXT12//'.')
          ENDIF
          CALL LCMSIX(IPDRL,'DEPL-CHAIN',1)
          CALL LCMGET(IPDRL,'STATE-VECTOR',ISTATE)
          NDEPL=ISTATE(1)
          NDFI=ISTATE(2)
          NDFP=ISTATE(3)
          NHEAVY=ISTATE(4)
          NLIGHT=ISTATE(5)
          NOTHER=ISTATE(6)
          NSTABL=ISTATE(7)
          NREAC=ISTATE(8)
          NPAR=ISTATE(9)
          CALL SETARA(IBASE,3*NDEPL,INAM)
          CALL SETARA(IBASE,NDEPL,IIZAE)
          CALL SETARA(IBASE,2*NREAC,IHREAC)
          CALL SETARA(IBASE,NREAC*NDEPL,IDR)
          CALL SETARA(RBASE,NREAC*NDEPL,IRER)
          CALL SETARA(RBASE,NDEPL,IRRD)
          CALL SETARA(IBASE,NPAR*NDEPL,IKPAR)
          CALL SETARA(RBASE,NPAR*NDEPL,IBPAR)
          IF(NDFP.GT.0) CALL SETARA(RBASE,NDFI*NDFP,IYIELD)
          CALL LCMGET(IPDRL,'STATE-VECTOR',ISTATE)
          CALL LCMGET(IPDRL,'ISOTOPESDEPL',IBASE(INAM))
          CALL LCMGET(IPDRL,'CHARGEWEIGHT',IBASE(IIZAE))
          CALL LCMGET(IPDRL,'DEPLETE-IDEN',IBASE(IHREAC))
          CALL LCMGET(IPDRL,'DEPLETE-REAC',IBASE(IDR))
          CALL LCMGET(IPDRL,'DEPLETE-ENER',RBASE(IRER))
          CALL LCMGET(IPDRL,'DEPLETE-DECA',RBASE(IRRD))
          CALL LCMGET(IPDRL,'PRODUCE-REAC',IBASE(IKPAR))
          CALL LCMGET(IPDRL,'PRODUCE-RATE',RBASE(IBPAR))
          IF(NDFP.GT.0) CALL LCMGET(IPDRL,'FISSIONYIELD',RBASE(IYIELD))
          CALL LCMSIX(IPDRL,' ',2)
          IF(TEXT12.NE.NAMLCM) CALL LCMCL(IPDRL,1)
          GO TO 20
        ELSE IF(HHLIB.EQ.'WIMS') THEN
          CALL LIBEWI(CFILNA,NEL)
          IEVOT=2
        ELSE IF(HHLIB.EQ.'WIMSD4') THEN
          CALL LIBENI(CFILNA,NEL)
          IEVOT=3
        ELSE IF(HHLIB.EQ.'APLIB2') THEN
          CALL LIBEAI(CFILNA,NEL)
          IEVOT=4
        ELSE IF(HHLIB.EQ.'NDAS') THEN
          CALL LIBND5(CFILNA,NEL)
          IEVOT=5
        ENDIF
      ELSE
        CALL XABORT('LIBDEP: INVALID KEY WORD.')
      ENDIF
      IF(IEVOT.EQ.0.OR.IEVOT.GT.1) THEN
*----
*  ALLOCATE/INITIALIZE WORK VECTORS FOR WIMS-AECL, WIMSD4
*  AND INPUT FILE
*----
        CALL SETARA(IBASE,3*NEL,ITNAM)
        CALL SETARA(IBASE,NEL,ITZEA)
        CALL SETARA(IBASE,NEL,MATNO)
        CALL SETARA(IBASE,(NEL+MAXR)*NEL,JKPAX)
        CALL SETARA(RBASE,(NEL+MAXR)*NEL,JBPAX)
        TEXT4='    '
        READ(TEXT4,'(A4)') ITEXT4
        CALL XDISET(IBASE(ITNAM),3*NEL,ITEXT4)
        CALL XDISET(IBASE(ITZEA),NEL,0)
        CALL XDISET(IBASE(MATNO),NEL,0)
        CALL XDISET(IBASE(JKPAX),(NEL+MAXR)*NEL,0)
        CALL XDRSET(RBASE(JBPAX),(NEL+MAXR)*NEL,0.0)
        IF(IEVOT.EQ.0) THEN
          CALL LIBEIR(MAXR,NEL,NMDEPL,IBASE(ITNAM),IBASE(ITZEA),
     >                IBASE(JKPAX),RBASE(JBPAX))
        ELSE IF(IEVOT.EQ.2) THEN
          CALL LIBEWR(CFILNA,MAXR,NEL,IBASE(ITNAM),IBASE(JKPAX),
     >                RBASE(JBPAX))
        ELSE IF(IEVOT.EQ.3) THEN
          CALL LIBENR(CFILNA,MAXR,NEL,IBASE(ITNAM),IBASE(JKPAX),
     >                RBASE(JBPAX))
        ELSE IF(IEVOT.EQ.4) THEN
          CALL LIBEAR(CFILNA,MAXR,NEL,NMDEPL,IBASE(ITNAM),
     >                IBASE(ITZEA),IBASE(JKPAX),RBASE(JBPAX))
        ELSE IF(IEVOT.EQ.5) THEN
          CALL SETARA(IBASE,2*NEL,ICHILD)
          CALL SETARA(RBASE,2*NEL,IBURND)
          CALL SETARA(IBASE,NEL,IIWISO)
          CALL LIBND6(CFILNA,MAXR,NEL,NMDEPL,IBASE(ITNAM),
     >                IBASE(ITZEA),IBASE(JKPAX),RBASE(JBPAX),
     >                IBASE(ICHILD),RBASE(IBURND),IBASE(IIWISO))
          CALL RLSARA(RBASE(IIWISO))
          CALL RLSARA(RBASE(IBURND))
          CALL RLSARA(IBASE(ICHILD))
        ENDIF
        CALL LIBWET(MAXR,NEL,NSTATE,NMDEPL,IBASE(ITNAM),ISTATE,
     >              IBASE(MATNO),IBASE(JKPAX),RBASE(JBPAX))
        NDEPL=ISTATE(1)
        NDFI=ISTATE(2)
        NDFP=ISTATE(3)
        NHEAVY=ISTATE(4)
        NLIGHT=ISTATE(5)
        NOTHER=ISTATE(6)
        NSTABL=ISTATE(7)
        NREAC=ISTATE(8)
        NPAR=ISTATE(9)
      ENDIF
*----
*  ALLOCATE DECAY CHAIN
*----
      NDEPL=MAX(NDEPL,1)
      NDFI=MAX(NDFI,1)
      NDFP=MAX(NDFP,1)
      CALL SETARA(IBASE,3*NDEPL,INAM)
      CALL SETARA(IBASE,NDEPL,IIZAE)
      CALL SETARA(IBASE,NREAC*NDEPL,IDR)
      CALL SETARA(RBASE,NREAC*NDEPL,IRER)
      CALL SETARA(RBASE,NDEPL,IRRD)
      CALL SETARA(IBASE,NPAR*NDEPL,IKPAR)
      CALL SETARA(RBASE,NPAR*NDEPL,IBPAR)
      CALL SETARA(RBASE,NDFI*NDFP,IYIELD)
*----
*  SET DECAY CHAIN
*----
      CALL LIBWED(MAXR,NEL,NDEPL,NDFI,NDFP,NHEAVY,NLIGHT,
     >            NOTHER,NSTABL,NREAC,NPAR,IBASE(ITNAM),
     >            IBASE(ITZEA),IBASE(MATNO),IBASE(JKPAX),
     >            RBASE(JBPAX),IBASE(INAM),IBASE(IIZAE),
     >            IBASE(IDR),RBASE(IRER),RBASE(IRRD),
     >            IBASE(IKPAR),RBASE(IBPAR),RBASE(IYIELD))
*----
*  RELEASE WORK VECTORS FOR WIMS-AECL, WIMS-NEA, DRAGLIB
*  AND INPUT FILE
*----
      CALL RLSARA(RBASE(JBPAX))
      CALL RLSARA(IBASE(JKPAX))
      CALL RLSARA(IBASE(MATNO))
      CALL RLSARA(IBASE(ITZEA))
      CALL RLSARA(IBASE(ITNAM))
*----
*  SELECT USED DEPLETION REACTION NAMES
*----
      CALL SETARA(IBASE,2*NREAC,IHREAC)
      DO 10 I=1,NREAC
        READ(NMDEPL(I),'(2A4)') (IBASE(IHREAC+2*(I-1)+J),J=0,1)
   10 CONTINUE
*----
*  PRINT DECAY CHAIN IF REQUIRED
*----
   20 CALL LIBEPR(IMPX,NDEPL,NSTABL,NDFI,NDFP,NREAC,NPAR,IBASE(INAM),
     >            IBASE(IHREAC),IBASE(IDR),RBASE(IRER),RBASE(IRRD),
     >            IBASE(IKPAR),RBASE(IBPAR),RBASE(IYIELD),IBASE(IIZAE))
*----
*  SAVE CHAIN
*----
      CALL LCMSIX(IPLIB,'DEPL-CHAIN',1)
      CALL LCMPUT(IPLIB,'STATE-VECTOR',NSTATE,1,ISTATE)
      CALL LCMPUT(IPLIB,'ISOTOPESDEPL',3*NDEPL,3,IBASE(INAM))
      CALL LCMPUT(IPLIB,'CHARGEWEIGHT',NDEPL,1,IBASE(IIZAE))
      CALL LCMPUT(IPLIB,'DEPLETE-IDEN',2*NREAC,3,IBASE(IHREAC))
      CALL LCMPUT(IPLIB,'DEPLETE-REAC',NREAC*NDEPL,1,IBASE(IDR))
      CALL LCMPUT(IPLIB,'DEPLETE-ENER',NREAC*NDEPL,2,RBASE(IRER))
      CALL LCMPUT(IPLIB,'DEPLETE-DECA',NDEPL,2,RBASE(IRRD))
      CALL LCMPUT(IPLIB,'PRODUCE-REAC',NPAR*NDEPL,1,IBASE(IKPAR))
      CALL LCMPUT(IPLIB,'PRODUCE-RATE',NPAR*NDEPL,2,RBASE(IBPAR))
      IF(NDFP.GT.0) CALL LCMPUT(IPLIB,'FISSIONYIELD',NDFI*NDFP,2,
     > RBASE(IYIELD))
      CALL LCMSIX(IPLIB,' ',2)
      IF(IMPX.GE.2) WRITE(IOUT,6000) (ISTATE(ISTA),ISTA=1,9)
*----
*  RELEASE DECAY CHAIN
*----
      CALL RLSARA(IBASE(IHREAC))
      IF(NDFP.GT.0) CALL RLSARA(RBASE(IYIELD))
      CALL RLSARA(RBASE(IBPAR))
      CALL RLSARA(IBASE(IKPAR))
      CALL RLSARA(RBASE(IRER))
      CALL RLSARA(RBASE(IRRD))
      CALL RLSARA(IBASE(IDR))
      CALL RLSARA(IBASE(IIZAE))
      CALL RLSARA(IBASE(INAM))
      RETURN
*----
*  FORMAT
*----
 6000 FORMAT(/' STATE-VECTOR FOR DEPLETION CHAIN'/' -------'/
     >  ' NDEPL  ',I6,' (NUMBER OF DEPLETING ISOTOPES)'/
     >  ' NDFI   ',I6,' (NUMBER OF DIRECT FISSILE ISOTOPES)'/
     >  ' NDFP   ',I6,' (NUMBER OF DIRECT FISSION PRODUCT)'/
     >  ' NHEAVY ',I6,' (NUMBER OF HEAVY ISOTOPES)'/
     >  ' NLIGHT ',I6,' (NUMBER OF FISSION PRODUCTS)'/
     >  ' NOTHER ',I6,' (NUMBER OF OTHER ISOTOPES)'/
     >  ' NSTABL ',I6,' (NUMBER OF STABLE ISOTOPES PRODUCING ENERGY)'/
     >  ' NREAC  ',I6,' (MAXIMUM NUMBER OF DEPLETION REACTIONS)'/
     >  ' NPAR   ',I6,' (MAXIMUM NUMBER OF PARENT REACTIONS)'/)
      END

==> version4_v4.0.7_lgpl.tgz: Version4_lgpl/Dragon/src/LIBDEP.f <==
*DECK LIBDEP
      SUBROUTINE LIBDEP(IPLIB,IMPX,NDEPL)
*
*-----------------------------------------------------------------------
*
*Purpose:
* read the information related to the depletion calculation.
*
*Copyright:
* Copyright (C) 2002 Ecole Polytechnique de Montreal
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
*
*Author(s): A. Hebert and G. Marleau
*
*Parameters: input
* IPLIB   pointer to the internal microscopic cross section library
*         (L_LIBRARY signature).
* IMPX    print flag.
*
*Parameters: output
* NDEPL   number of depleting isotopes.
*
*-----------------------------------------------------------------------
*
      IMPLICIT NONE
*----
*  SUBROUTINE ARGUMENTS
*----
      INTEGER IPLIB,IMPX,NDEPL
*----
*  LOCAL PARAMETERS
*----
      INTEGER          IOUT,NSTATE,MAXR,INDIC,NEL,IEVOT,NITMA,IPDRL,
     >                 NDFI,NDFP,NHEAVY,NLIGHT,NOTHER,NSTABL,NREAC,
     >                 NPAR,INAM,IIZAE,IHREAC,IDR,IRER,IRRD,IKPAR,
     >                 IBPAR,IYIELD,ITNAM,ITZEA,MATNO,JKPAX,JBPAX,
     >                 ITEXT4,I,J,ISTA,ILONG,ITYLCM,ICHILD,IBURND,
     >                 IIWISO
      REAL             FLOTT,RBASE
      PARAMETER       (IOUT=6,NSTATE=40,MAXR=12)
      DOUBLE PRECISION DBLINP
      CHARACTER        NMDEPL(MAXR)*8,TEXT4*4,HSMG*131,CFILNA*64,
     >                 HHLIB*6,TEXT12*12,NAMLCM*12,NAMMY*12
      LOGICAL          EMPTY,LCM
      INTEGER          ISTATE(NSTATE)
*----
*  MEMORY ALLOCATION
*----
      INTEGER          IBASE(1)
      COMMON           RBASE(1)
      EQUIVALENCE     (RBASE(1),IBASE(1))
*
      SAVE      NMDEPL
      DATA      NMDEPL/'DECAY   ','NFTOT   ','NG      ','N2N     ',
     >                 'N3N     ','N4N     ','NA      ','NP      ',
     >                 'N2A     ','NNP     ','ND      ','NT      '/
*----
*  READ INFORMATION AVAILABLE ON INPUT
*----
      IEVOT=1
      CALL REDGET(INDIC,NEL,FLOTT,TEXT4,DBLINP)
      IF(INDIC.EQ.1) THEN
         IEVOT=0
      ELSE IF((INDIC.EQ.3).AND.(TEXT4.EQ.'LIB:')) THEN
        CALL REDGET(INDIC,NITMA,FLOTT,HHLIB,DBLINP)
        IF(INDIC.NE.3) THEN
          CALL XABORT('LIBDEP: CHARACTER LIBRARY NAME REQUIRED.')
        ELSE IF((HHLIB.NE.'DRAGON  ') .AND. (HHLIB.NE.'WIMS    ') .AND.
     >          (HHLIB.NE.'WIMSD4  ') .AND. (HHLIB.NE.'APLIB2  ') .AND.
     >          (HHLIB.NE.'NDAS    ')       ) THEN
          WRITE(HSMG,'(30HLIBDEP: INVALID EVOL LIB TYPE ,A6)') HHLIB
          CALL XABORT(HSMG)
        ENDIF
        CALL REDGET(INDIC,NITMA,FLOTT,TEXT4,DBLINP)
        IF((INDIC.NE.3).OR.(TEXT4.NE.'FIL:'))
     >    CALL XABORT('LIBDEP: FIL: EXPECTED.')
        CFILNA=' '
        CALL REDGET(INDIC,NITMA,FLOTT,CFILNA,DBLINP)
        IF(INDIC.NE.3) CALL XABORT('LIBDEP: CHARACTER DATA EXPECTED.')
        IF(HHLIB.EQ.'DRAGON') THEN
          TEXT12=CFILNA(:12)
          CALL LCMINF(IPLIB,NAMLCM,NAMMY,EMPTY,ILONG,LCM)
          IF(TEXT12.EQ.NAMLCM) THEN
            IPDRL=IPLIB
          ELSE
            CALL LCMOP(IPDRL,TEXT12,2,2,0)
          ENDIF
          CALL LCMLEN(IPDRL,'DEPL-CHAIN',ILONG,ITYLCM)
          IF(ILONG.EQ.0) THEN
             CALL XABORT('LIBDEP: NO BURNUP DATA ON DRAGLIB NAMED '//
     >       TEXT12//'.')
          ENDIF
          CALL LCMSIX(IPDRL,'DEPL-CHAIN',1)
          CALL LCMGET(IPDRL,'STATE-VECTOR',ISTATE)
          NDEPL=ISTATE(1)
          NDFI=ISTATE(2)
          NDFP=ISTATE(3)
          NHEAVY=ISTATE(4)
          NLIGHT=ISTATE(5)
          NOTHER=ISTATE(6)
          NSTABL=ISTATE(7)
          NREAC=ISTATE(8)
          NPAR=ISTATE(9)
          CALL SETARA(IBASE,3*NDEPL,INAM)
          CALL SETARA(IBASE,NDEPL,IIZAE)
          CALL SETARA(IBASE,2*NREAC,IHREAC)
          CALL SETARA(IBASE,NREAC*NDEPL,IDR)
          CALL SETARA(RBASE,NREAC*NDEPL,IRER)
          CALL SETARA(RBASE,NDEPL,IRRD)
          CALL SETARA(IBASE,NPAR*NDEPL,IKPAR)
          CALL SETARA(RBASE,NPAR*NDEPL,IBPAR)
          IF(NDFP.GT.0) CALL SETARA(RBASE,NDFI*NDFP,IYIELD)
          CALL LCMGET(IPDRL,'STATE-VECTOR',ISTATE)
          CALL LCMGET(IPDRL,'ISOTOPESDEPL',IBASE(INAM))
          CALL LCMGET(IPDRL,'CHARGEWEIGHT',IBASE(IIZAE))
          CALL LCMGET(IPDRL,'DEPLETE-IDEN',IBASE(IHREAC))
          CALL LCMGET(IPDRL,'DEPLETE-REAC',IBASE(IDR))
          CALL LCMGET(IPDRL,'DEPLETE-ENER',RBASE(IRER))
          CALL LCMGET(IPDRL,'DEPLETE-DECA',RBASE(IRRD))
          CALL LCMGET(IPDRL,'PRODUCE-REAC',IBASE(IKPAR))
          CALL LCMGET(IPDRL,'PRODUCE-RATE',RBASE(IBPAR))
          IF(NDFP.GT.0) CALL LCMGET(IPDRL,'FISSIONYIELD',RBASE(IYIELD))
          CALL LCMSIX(IPDRL,' ',2)
          IF(TEXT12.NE.NAMLCM) CALL LCMCL(IPDRL,1)
          GO TO 20
        ELSE IF(HHLIB.EQ.'WIMS') THEN
          CALL LIBEWI(CFILNA,NEL)
          IEVOT=2
        ELSE IF(HHLIB.EQ.'WIMSD4') THEN
          CALL LIBENI(CFILNA,NEL)
          IEVOT=3
        ELSE IF(HHLIB.EQ.'APLIB2') THEN
          CALL LIBEAI(CFILNA,NEL)
          IEVOT=4
        ELSE IF(HHLIB.EQ.'NDAS') THEN
          CALL LIBND5(CFILNA,NEL)
          IEVOT=5
        ENDIF
      ELSE
        CALL XABORT('LIBDEP: INVALID KEY WORD.')
      ENDIF
      IF(IEVOT.EQ.0.OR.IEVOT.GT.1) THEN
*----
*  ALLOCATE/INITIALIZE WORK VECTORS FOR WIMS-AECL, WIMSD4
*  AND INPUT FILE
*----
        CALL SETARA(IBASE,3*NEL,ITNAM)
        CALL SETARA(IBASE,NEL,ITZEA)
        CALL SETARA(IBASE,NEL,MATNO)
        CALL SETARA(IBASE,(NEL+MAXR)*NEL,JKPAX)
        CALL SETARA(RBASE,(NEL+MAXR)*NEL,JBPAX)
        TEXT4='    '
        READ(TEXT4,'(A4)') ITEXT4
        CALL XDISET(IBASE(ITNAM),3*NEL,ITEXT4)
        CALL XDISET(IBASE(ITZEA),NEL,0)
        CALL XDISET(IBASE(MATNO),NEL,0)
        CALL XDISET(IBASE(JKPAX),(NEL+MAXR)*NEL,0)
        CALL XDRSET(RBASE(JBPAX),(NEL+MAXR)*NEL,0.0)
        IF(IEVOT.EQ.0) THEN
          CALL LIBEIR(MAXR,NEL,NMDEPL,IBASE(ITNAM),IBASE(ITZEA),
     >                IBASE(JKPAX),RBASE(JBPAX))
        ELSE IF(IEVOT.EQ.2) THEN
          CALL LIBEWR(CFILNA,MAXR,NEL,IBASE(ITNAM),IBASE(JKPAX),
     >                RBASE(JBPAX))
        ELSE IF(IEVOT.EQ.3) THEN
          CALL LIBENR(CFILNA,MAXR,NEL,IBASE(ITNAM),IBASE(JKPAX),
     >                RBASE(JBPAX))
        ELSE IF(IEVOT.EQ.4) THEN
          CALL LIBEAR(CFILNA,MAXR,NEL,NMDEPL,IBASE(ITNAM),
     >                IBASE(ITZEA),IBASE(JKPAX),RBASE(JBPAX))
        ELSE IF(IEVOT.EQ.5) THEN
          CALL SETARA(IBASE,2*NEL,ICHILD)
          CALL SETARA(RBASE,2*NEL,IBURND)
          CALL SETARA(IBASE,NEL,IIWISO)
          CALL LIBND6(CFILNA,MAXR,NEL,IBASE(ITNAM),IBASE(JKPAX),
     >                RBASE(JBPAX),IBASE(ICHILD),RBASE(IBURND),
     >                IBASE(IIWISO))
          CALL RLSARA(RBASE(IIWISO))
          CALL RLSARA(RBASE(IBURND))
          CALL RLSARA(IBASE(ICHILD))
        ENDIF
        CALL LIBWET(MAXR,NEL,NSTATE,NMDEPL,IBASE(ITNAM),ISTATE,
     >              IBASE(MATNO),IBASE(JKPAX),RBASE(JBPAX))
        NDEPL=ISTATE(1)
        NDFI=ISTATE(2)
        NDFP=ISTATE(3)
        NHEAVY=ISTATE(4)
        NLIGHT=ISTATE(5)
        NOTHER=ISTATE(6)
        NSTABL=ISTATE(7)
        NREAC=ISTATE(8)
        NPAR=ISTATE(9)
      ENDIF
*----
*  ALLOCATE DECAY CHAIN
*----
      NDEPL=MAX(NDEPL,1)
      NDFI=MAX(NDFI,1)
      NDFP=MAX(NDFP,1)
      CALL SETARA(IBASE,3*NDEPL,INAM)
      CALL SETARA(IBASE,NDEPL,IIZAE)
      CALL SETARA(IBASE,NREAC*NDEPL,IDR)
      CALL SETARA(RBASE,NREAC*NDEPL,IRER)
      CALL SETARA(RBASE,NDEPL,IRRD)
      CALL SETARA(IBASE,NPAR*NDEPL,IKPAR)
      CALL SETARA(RBASE,NPAR*NDEPL,IBPAR)
      CALL SETARA(RBASE,NDFI*NDFP,IYIELD)
*----
*  SET DECAY CHAIN
*----
      CALL LIBWED(MAXR,NEL,NDEPL,NDFI,NDFP,NHEAVY,NLIGHT,
     >            NOTHER,NREAC,NPAR,IBASE(ITNAM),
     >            IBASE(ITZEA),IBASE(MATNO),IBASE(JKPAX),
     >            RBASE(JBPAX),IBASE(INAM),IBASE(IIZAE),
     >            IBASE(IDR),RBASE(IRER),RBASE(IRRD),
     >            IBASE(IKPAR),RBASE(IBPAR),RBASE(IYIELD))
*----
*  RELEASE WORK VECTORS FOR WIMS-AECL, WIMS-NEA, DRAGLIB
*  AND INPUT FILE
*----
      CALL RLSARA(RBASE(JBPAX))
      CALL RLSARA(IBASE(JKPAX))
      CALL RLSARA(IBASE(MATNO))
      CALL RLSARA(IBASE(ITZEA))
      CALL RLSARA(IBASE(ITNAM))
*----
*  SELECT USED DEPLETION REACTION NAMES
*----
      CALL SETARA(IBASE,2*NREAC,IHREAC)
      DO 10 I=1,NREAC
        READ(NMDEPL(I),'(2A4)') (IBASE(IHREAC+2*(I-1)+J),J=0,1)
   10 CONTINUE
*----
*  PRINT DECAY CHAIN IF REQUIRED
*----
   20 CALL LIBEPR(IMPX,NDEPL,NSTABL,NDFI,NDFP,NREAC,NPAR,IBASE(INAM),
     >            IBASE(IHREAC),IBASE(IDR),RBASE(IRER),RBASE(IRRD),
     >            IBASE(IKPAR),RBASE(IBPAR),RBASE(IYIELD),IBASE(IIZAE))
*----
*  SAVE CHAIN
*----
      CALL LCMSIX(IPLIB,'DEPL-CHAIN',1)
      CALL LCMPUT(IPLIB,'STATE-VECTOR',NSTATE,1,ISTATE)
      CALL LCMPUT(IPLIB,'ISOTOPESDEPL',3*NDEPL,3,IBASE(INAM))
      CALL LCMPUT(IPLIB,'CHARGEWEIGHT',NDEPL,1,IBASE(IIZAE))
      CALL LCMPUT(IPLIB,'DEPLETE-IDEN',2*NREAC,3,IBASE(IHREAC))
      CALL LCMPUT(IPLIB,'DEPLETE-REAC',NREAC*NDEPL,1,IBASE(IDR))
      CALL LCMPUT(IPLIB,'DEPLETE-ENER',NREAC*NDEPL,2,RBASE(IRER))
      CALL LCMPUT(IPLIB,'DEPLETE-DECA',NDEPL,2,RBASE(IRRD))
      CALL LCMPUT(IPLIB,'PRODUCE-REAC',NPAR*NDEPL,1,IBASE(IKPAR))
      CALL LCMPUT(IPLIB,'PRODUCE-RATE',NPAR*NDEPL,2,RBASE(IBPAR))
      IF(NDFP.GT.0) CALL LCMPUT(IPLIB,'FISSIONYIELD',NDFI*NDFP,2,
     > RBASE(IYIELD))
      CALL LCMSIX(IPLIB,' ',2)
      IF(IMPX.GE.2) WRITE(IOUT,6000) (ISTATE(ISTA),ISTA=1,9)
*----
*  RELEASE DECAY CHAIN
*----
      CALL RLSARA(IBASE(IHREAC))
      IF(NDFP.GT.0) CALL RLSARA(RBASE(IYIELD))
      CALL RLSARA(RBASE(IBPAR))
      CALL RLSARA(IBASE(IKPAR))
      CALL RLSARA(RBASE(IRER))
      CALL RLSARA(RBASE(IRRD))
      CALL RLSARA(IBASE(IDR))
      CALL RLSARA(IBASE(IIZAE))
      CALL RLSARA(IBASE(INAM))
      RETURN
*----
*  FORMAT
*----
 6000 FORMAT(/' STATE-VECTOR FOR DEPLETION CHAIN'/' -------'/
     >  ' NDEPL  ',I6,' (NUMBER OF DEPLETING ISOTOPES)'/
     >  ' NDFI   ',I6,' (NUMBER OF DIRECT FISSILE ISOTOPES)'/
     >  ' NDFP   ',I6,' (NUMBER OF DIRECT FISSION PRODUCT)'/
     >  ' NHEAVY ',I6,' (NUMBER OF HEAVY ISOTOPES)'/
     >  ' NLIGHT ',I6,' (NUMBER OF FISSION PRODUCTS)'/
     >  ' NOTHER ',I6,' (NUMBER OF OTHER ISOTOPES)'/
     >  ' NSTABL ',I6,' (NUMBER OF STABLE ISOTOPES PRODUCING ENERGY)'/
     >  ' NREAC  ',I6,' (MAXIMUM NUMBER OF DEPLETION REACTIONS)'/
     >  ' NPAR   ',I6,' (MAXIMUM NUMBER OF PARENT REACTIONS)'/)
      END
